#####################################################################################
# returns the studentized residuals of a multivariate linear model			#
# however standardization is NOT done multivariate, but univariate fashion 		#
#####################################################################################

rstudent.manylm <- function(model, ...) {

    warning("Not implemented for manylm objects. Return rstandard(model) instead. \n")
    rstandard.manylm(mode)

}
